/*
 * Copyright (c) 1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *
 * 4. The names "Java Apache Element Construction Set", "Java Apache ECS" and 
 *    "Java Apache Project" must not be used to endorse or promote products 
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called 
 *    "Java Apache Element Construction Set" nor "Java Apache ECS" appear 
 *    in their names without prior written permission of the 
 *    Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *    
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Project. For more information
 * on the Java Apache Project please see <http://java.apache.org/>.
 *
 */
package org.apache.ecs;

/**
    This class creates an &lt;IMG&gt; tag.

    @version $Id: IMG.java,v 1.1.1.1 1999/04/20 01:18:57 jonbolt Exp $
    @author <a href="mailto:snagy@servletapi.com">Stephan Nagy</a>
    @author <a href="mailto:jon@clearink.com">Jon S. Stevens</a>
*/
public class IMG extends SinglePartElement
{
    /**
            Private initialization routine.
    */

    {
        setHtmlElementType("img");
    }

    /**
        Basic constructor. Use the set* methods to set the attibutes.
    */
    public IMG()
    {
    }

    /**
        Creates an IMG tag

        @param   src  the SRC="" attribute
    */
    public IMG(String src)
    {
        setSrc(src);
    }

    /**
        Creates an IMG tag

        @param   src  the SRC="" attribute
        @param   border  the BORDER="" attribute
    */
    public IMG(String src, int border)
    {
        setSrc(src);
        setBorder(border);
    }

    /**
        Creates an IMG tag

        @param   src  the SRC="" attribute
        @param   name  the NAME="" attribute
    */
    public IMG(String src, String name)
    {
        setSrc(src);
        setName(name);
    }

    /**
        Creates an IMG tag

        @param   src  the SRC="" attribute
        @param   name  the NAME="" attribute
        @param   border  the BORDER="" attribute
    */
    public IMG(String src, String name, int border)
    {
        setSrc(src);
        setName(name);
        setBorder(border);
    }

    /**
        Sets the SRC="" attribute
        @param   src  the SRC="" attribute
    */
    public IMG setSrc(String src)
    {
        addAttribute("src",src);
        return this;
    }

    /**
        Sets the BORDER="" attribute
        @param   border  the BORDER="" attribute
    */
    public IMG setBorder(int border)
    {
        addAttribute("border",Integer.toString(border));
        return this;
    }

    /**
        Sets the NAME="" attribute
        @param   name  the NAME="" attribute
    */
    public IMG setName(String name)
    {
        addAttribute("name",name);
        return this;
    }

    /**
        Sets the HEIGHT="" attribute
        @param   height  the HEIGHT="" attribute
    */
    public IMG setHeight(String height)
    {
        addAttribute("height",height);
        return this;
    }

    /**
        Sets the HEIGHT="" attribute
        @param   height  the HEIGHT="" attribute
    */
    public IMG setHeight(int height)
    {
        addAttribute("height",Integer.toString(height));
        return this;
    }

    /**
        Sets the WIDTH="" attribute
        @param   width  the WIDTH="" attribute
    */
    public IMG setWidth(String width)
    {
        addAttribute("width",width);
        return this;
    }

    /**
        Sets the WIDTH="" attribute
        @param   width  the WIDTH="" attribute
    */
    public IMG setWidth(int width)
    {
        addAttribute("width",Integer.toString(width));
        return this;
    }

    /**
        Sets the ALT="" attribute
        @param   alt  the ALT="" attribute
    */
    public IMG setAlt(String alt)
    {
        addAttribute("alt",alt);
        return this;
    }

    /**
        Sets the ISMAP attribute
        @param   ismap  the ISMAP attribute
    */
    public IMG setIsMap(boolean ismap)
    {
        if(ismap == true)
            addAttribute("ismap",NO_ATTRIBUTE_VALUE);
        else
            removeAttribute("ismap");
            
        return this;
    }

    /**
        Sets the USMAP="" attribute
        @param   usemap  the USMAP="" attribute
    */
    public IMG setUseMap(String usemap)
    {
        addAttribute("usemap",usemap);
        return this;
    }

    /**
        Sets the ALIGN="" attribute
        @param   align  the ALIGN="" attribute
    */
    public IMG setAlign(String align)
    {
        addAttribute("align",align);
        return this;
    }

    /**
        Sets the HSPACE="" attribute
        @param   hspace  the HSPACE="" attribute
    */
    public IMG setHspace(String hspace)
    {
        addAttribute("hspace",hspace);
        return this;
    }

    /**
        Sets the HSPACE="" attribute
        @param   hspace  the HSPACE="" attribute
    */
    public IMG setHspace(int hspace)
    {
        addAttribute("hspace",Integer.toString(hspace));
        return this;
    }

    /**
        Sets the VSPACE="" attribute
        @param   vspace  the VSPACE="" attribute
    */
    public IMG setVspace(String vspace)
    {
        addAttribute("vspace",vspace);
        return this;
    }

    /**
        Sets the VSPACE="" attribute
        @param   vspace  the VSPACE="" attribute
    */
    public IMG setVspace(int vspace)
    {
        addAttribute("vspace",Integer.toString(vspace));
        return this;
    }
}