/*
 * Copyright (c) 1999 The Java Apache Project.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. All advertising materials mentioning features or use of this
 *    software must display the following acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *
 * 4. The names "Java Apache Element Construction Set", "Java Apache ECS" and 
 *    "Java Apache Project" must not be used to endorse or promote products 
 *    derived from this software without prior written permission.
 *
 * 5. Products derived from this software may not be called 
 *    "Java Apache Element Construction Set" nor "Java Apache ECS" appear 
 *    in their names without prior written permission of the 
 *    Java Apache Project.
 *
 * 6. Redistributions of any form whatsoever must retain the following
 *    acknowledgment:
 *    "This product includes software developed by the Java Apache 
 *    Project. <http://java.apache.org/>"
 *    
 * THIS SOFTWARE IS PROVIDED BY THE JAVA APACHE PROJECT "AS IS" AND ANY
 * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE JAVA APACHE PROJECT OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Java Apache Project. For more information
 * on the Java Apache Project please see <http://java.apache.org/>.
 *
 */
package org.apache.ecs;

import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.IOException;
import java.util.Hashtable;
import java.util.Enumeration;

/**
    This class describes a extends Element to create a singlepart
    element.

    @version $Id: SinglePartElement.java,v 1.1.1.1 1999/04/20 01:18:58 jonbolt Exp $
    @author <a href="mailto:snagy@servletapi.com">Stephan Nagy</a>
    @author <a href="mailto:jon@clearink.com">Jon S. Stevens</a>
*/
public class SinglePartElement extends ElementAttributes
{

    /**
        Default constructor.  Use set* methods to define the element.
        A SinglePartElement is defined as an element having juse &lt;a begin tag&gt;
     */
    public SinglePartElement()
    {
        setNeedClosingTag(false);
    }

    /**
        Default constructor.  Use set* methods to define the element.
        A SinglePartElement is defined as an element having juse &lt;a begin tag&gt;
        @param element_tag Defines what the &lt;tag&gt; should be.
    */
    public SinglePartElement(String element_tag)
    {
        setHtmlElementType(element_tag);
        setNeedClosingTag(false);
    }

    /**
        Write the element to the designated output stream.
    */
    public void output(OutputStream out)
    {

        Hashtable ce = (Hashtable) getElementHashEntry().clone();
        String html_content = new String();

        try
        {
            String html_tag = (String) ce.get("_tag");
            ce.remove("_tag"); // get rid of the tag

            out.write('<');
            out.write(alterCase(html_tag).getBytes());
            Enumeration enum = ce.keys();
            String value = new String();
            
            while (enum.hasMoreElements())
            {

                String tag = (String) enum.nextElement();
                if(getAttributeFilterState())
                {
                    value = getFilter().process((String) ce.get(tag));
                }
                else
                {
                    value = (String) ce.get(tag);
                }
                out.write(' ');
                out.write(alterCase(tag).getBytes());
                if(!value.equalsIgnoreCase(NO_ATTRIBUTE_VALUE))
                {
                    out.write('=');
                    out.write('"');
                    out.write(getFilter().process((String) ce.get(tag)).getBytes());
                    out.write('"');
                }

            }

            out.write('>');

        }
        catch (IOException ioe)
        {
        }
    }

    /**
        Write the element to the designated PrintWriter.
    */
    public void output(PrintWriter pw)
    {
        Hashtable ce = (Hashtable) getElementHashEntry().clone();
        String html_content = new String();

        String html_tag = (String) ce.get("_tag");
        ce.remove("_tag"); // get rid of the tag

        pw.write('<');
        pw.write(alterCase(html_tag));
        Enumeration enum = ce.keys();
        String value = new String(); // avoid repeated calls to create new string object.

        while (enum.hasMoreElements())
        {

            String tag = (String) enum.nextElement();
            if(getAttributeFilterState())
            {
                value = getFilter().process((String) ce.get(tag));
            }
            else
            {
                value = (String) ce.get(tag);
            }
            pw.write(' ');
            pw.write(alterCase(tag));
            if(!value.equalsIgnoreCase(NO_ATTRIBUTE_VALUE))
            {
                pw.write('=');
                pw.write('"');
                pw.write(value);
                pw.write('"');
            }
        }
        pw.write('>');
    }
}